@@ -1,9 +1,9 @@
 """Functions for computing accuracy scores for classification tasks."""
 
-from typing import Literal, Optional, Union
+from typing import Literal, Optional, Union, cast
 
 import numpy as np
-from numpy.typing import ArrayLike
+import numpy.typing as npt
 from sklearn.metrics._classification import _prf_divide
 
 from cyclops.evaluate.metrics.functional.stat_scores import (
@@ -22,14 +22,14 @@ from cyclops.evaluate.metrics.utils import (
 
 
 def _accuracy_reduce(  # pylint: disable=too-many-arguments
-    tp: Union[np.ndarray, np.int_],
-    fp: Union[np.ndarray, np.int_],
-    tn: Union[np.ndarray, np.int_],
-    fn: Union[np.ndarray, np.int_],
+    tp: Union[npt.NDArray[np.int_], np.int_],
+    fp: Union[npt.NDArray[np.int_], np.int_],
+    tn: Union[npt.NDArray[np.int_], np.int_],
+    fn: Union[npt.NDArray[np.int_], np.int_],
     task_type: Literal["binary", "multiclass", "multilabel"],
     average: Literal["micro", "macro", "weighted", None],
     zero_division: Literal["warn", 0, 1] = "warn",
-) -> Union[np.ndarray, float]:
+) -> Union[float, npt.NDArray[np.float_]]:
     """Compute accuracy score per class or sample and apply average.
 
     Parameters
@@ -54,16 +54,16 @@ def _accuracy_reduce(  # pylint: disable=too-many-arguments
 
     Returns
     -------
-        accuracy : numpy.ndarray or float
-            The average accuracy score if 'average' is not None, otherwise the
-            accuracy score per class.
+    accuracy : numpy.ndarray or float
+        The average accuracy score if 'average' is not None, otherwise the
+        accuracy score per class.
 
     """
     if average == "micro":
         tp = np.array(np.sum(tp))
         fn = np.array(np.sum(fn))
-        numerator = tp
-        denominator = tp + fn
+        numerator: Union[npt.NDArray[np.int_], np.int_] = tp
+        denominator: Union[npt.NDArray[np.int_], np.int_] = tp + fn
         if task_type == "multilabel":
             fp = np.array(np.sum(fp))
             tn = np.array(np.sum(tn))
@@ -94,19 +94,23 @@ def _accuracy_reduce(  # pylint: disable=too-many-arguments
 
         if weights is not None and np.sum(weights) == 0:
             return (
-                np.zeros_like(score)
+                np.zeros_like(score, dtype=np.float64)
                 if zero_division in ["warn", 0]
-                else np.ones_like(score)
+                else np.ones_like(score, dtype=np.float64)
             )
 
-        return np.average(score, weights=weights)
+        avg_score: Union[float, npt.NDArray[np.float_]] = np.average(
+            score, weights=weights
+        )
+        return avg_score
 
-    return _get_value_if_singleton_array(score)
+    ret_value = _get_value_if_singleton_array(score)
+    return cast(Union[float, npt.NDArray[np.float_]], ret_value)
 
 
 def binary_accuracy(  # pylint: disable=too-many-arguments
-    target: ArrayLike,
-    preds: ArrayLike,
+    target: npt.ArrayLike,
+    preds: npt.ArrayLike,
     pos_label: int = 1,
     threshold: float = 0.5,
     zero_division: Literal["warn", 0, 1] = "warn",
@@ -115,9 +119,9 @@ def binary_accuracy(  # pylint: disable=too-many-arguments
 
     Parameters
     ----------
-    target : ArrayLike
+    target : npt.ArrayLike
         Ground truth (correct) target values.
-    preds : ArrayLike
+    preds : npt.ArrayLike
         Estimated targets (predictions) as returned by a classifier.
     pos_label : int, default=1
         The label of the positive class. Can be 0 or 1.
@@ -131,7 +135,7 @@ def binary_accuracy(  # pylint: disable=too-many-arguments
 
     Returns
     -------
-    float
+    acc_score : float
         The accuracy score.
 
     Examples
@@ -154,26 +158,33 @@ def binary_accuracy(  # pylint: disable=too-many-arguments
     )
 
     tp, fp, tn, fn = _binary_stat_scores_update(target, preds, pos_label=pos_label)
-    return _accuracy_reduce(
-        tp, fp, tn, fn, task_type="binary", average=None, zero_division=zero_division
+    acc_score = _accuracy_reduce(
+        tp,
+        fp,
+        tn,
+        fn,
+        task_type="binary",
+        average=None,
+        zero_division=zero_division,
     )
+    return cast(float, acc_score)
 
 
 def multiclass_accuracy(  # pylint: disable=too-many-arguments
-    target: ArrayLike,
-    preds: ArrayLike,
+    target: npt.ArrayLike,
+    preds: npt.ArrayLike,
     num_classes: int,
     top_k: Optional[int] = None,
     average: Literal["micro", "macro", "weighted", None] = None,
     zero_division: Literal["warn", 0, 1] = "warn",
-) -> Union[float, np.ndarray]:
+) -> Union[float, npt.NDArray[np.float_]]:
     """Compute the accuracy score for multiclass classification problems.
 
     Parameters
     ----------
-    target : ArrayLike
+    target : npt.ArrayLike
         Ground truth (correct) target values.
-    preds : ArrayLike
+    preds : npt.ArrayLike
         Estimated targets (predictions) as returned by a classifier.
     num_classes : int
         Number of classes in the dataset.
@@ -230,26 +241,29 @@ def multiclass_accuracy(  # pylint: disable=too-many-arguments
     # pylint: disable=invalid-name
     tp, fp, tn, fn = _multiclass_stat_scores_update(target, preds, num_classes)
 
-    return _accuracy_reduce(
-        tp,
-        fp,
-        tn,
-        fn,
-        task_type="multiclass",
-        average=average,
-        zero_division=zero_division,
+    return cast(
+        float,
+        _accuracy_reduce(
+            tp,
+            fp,
+            tn,
+            fn,
+            task_type="multiclass",
+            average=average,
+            zero_division=zero_division,
+        ),
     )
 
 
 def multilabel_accuracy(  # pylint: disable=too-many-arguments
-    target: ArrayLike,
-    preds: ArrayLike,
+    target: npt.ArrayLike,
+    preds: npt.ArrayLike,
     num_labels: int,
     threshold: float = 0.5,
     top_k: Optional[int] = None,
     average: Literal["micro", "macro", "weighted", None] = None,
     zero_division: Literal["warn", 0, 1] = "warn",
-) -> Union[float, np.ndarray]:
+) -> Union[float, npt.NDArray[np.float_]]:
     """Compute the accuracy score for multilabel-indicator targets.
 
     Parameters
@@ -325,24 +339,24 @@ def multilabel_accuracy(  # pylint: disable=too-many-arguments
 
 
 def accuracy(  # pylint: disable=too-many-arguments
-    target: ArrayLike,
-    preds: ArrayLike,
+    target: npt.ArrayLike,
+    preds: npt.ArrayLike,
     task: Literal["binary", "multiclass", "multilabel"],
     pos_label: int = 1,
-    num_classes: int = None,
+    num_classes: Optional[int] = None,
     threshold: float = 0.5,
     top_k: Optional[int] = None,
-    num_labels: int = None,
+    num_labels: Optional[int] = None,
     average: Literal["micro", "macro", "weighted", None] = None,
     zero_division: Literal["warn", 0, 1] = "warn",
-) -> Union[float, np.ndarray]:
+) -> Union[float, npt.NDArray[np.float_]]:
     """Compute accuracy score for different classification tasks.
 
     Parameters
     ----------
-    target : ArrayLike
+    target : npt.ArrayLike
         Ground truth (correct) target values.
-    preds : ArrayLike
+    preds : npt.ArrayLike
         Estimated targets (predictions) as returned by a classifier.
     task : Literal["binary", "multiclass", "multilabel"]
         The type of task for the input data. One of 'binary', 'multiclass'
@@ -416,7 +430,7 @@ def accuracy(  # pylint: disable=too-many-arguments
 
     """
     if task == "binary":
-        accuracy_score = binary_accuracy(
+        accuracy_score: Union[float, npt.NDArray[np.float_]] = binary_accuracy(
             target,
             preds,
             pos_label=pos_label,
@@ -432,7 +446,7 @@ def accuracy(  # pylint: disable=too-many-arguments
             preds,
             num_classes=num_classes,
             top_k=top_k,
-            average=average,  # type: ignore
+            average=average,
             zero_division=zero_division,
         )
     elif task == "multilabel":
