@@ -1,9 +1,9 @@
 """Functions for computing F-beta and F1 scores for different input types."""
 
-from typing import Literal, Optional, Union
+from typing import Literal, Optional, Union, cast
 
 import numpy as np
-from numpy.typing import ArrayLike
+import numpy.typing as npt
 from sklearn.metrics._classification import _prf_divide
 
 from cyclops.evaluate.metrics.functional.stat_scores import (
@@ -22,13 +22,13 @@ from cyclops.evaluate.metrics.utils import (
 
 
 def _fbeta_reduce(  # pylint: disable=too-many-arguments
-    tp: np.ndarray,
-    fp: np.ndarray,
-    fn: np.ndarray,
+    tp: Union[npt.NDArray[np.int_], np.int_],
+    fp: Union[npt.NDArray[np.int_], np.int_],
+    fn: Union[npt.NDArray[np.int_], np.int_],
     beta: float,
     average: Literal["micro", "macro", "weighted", None],
     zero_division: Literal["warn", 0, 1] = "warn",
-) -> Union[float, np.ndarray]:
+) -> Union[float, npt.NDArray[np.float_]]:
     """Compute the F-beta score, a generalization of F-measure.
 
     Parameters
@@ -94,9 +94,9 @@ def _fbeta_reduce(  # pylint: disable=too-many-arguments
     if average == "weighted":
         weights = tp + fn
         if np.sum(weights) == 0:
-            result = np.ones_like(score)
+            result = np.ones_like(score, dtype=np.float64)
             if zero_division in ["warn", 0]:
-                result = np.zeros_like(score)
+                result = np.zeros_like(score, dtype=np.float64)
             return result
     else:
         weights = None
@@ -104,7 +104,7 @@ def _fbeta_reduce(  # pylint: disable=too-many-arguments
     if average is not None and score.ndim != 0 and len(score) > 1:
         result = np.average(score, weights=weights)
     else:
-        result = _get_value_if_singleton_array(score)
+        result = _get_value_if_singleton_array(score)  # type: ignore[assignment]
 
     return result
 
@@ -116,8 +116,8 @@ def _check_beta(beta: float) -> None:
 
 
 def binary_fbeta_score(  # pylint: disable=too-many-arguments
-    target: ArrayLike,
-    preds: ArrayLike,
+    target: npt.ArrayLike,
+    preds: npt.ArrayLike,
     beta: float,
     pos_label: int = 1,
     threshold: float = 0.5,
@@ -127,9 +127,9 @@ def binary_fbeta_score(  # pylint: disable=too-many-arguments
 
     Parameters
     ----------
-    target : ArrayLike
+    target : npt.ArrayLike
         Ground truth (correct) target values.
-    preds : ArrayLike
+    preds : npt.ArrayLike
         Predictions as returned by a classifier.
     beta : float
         Weight of precision in harmonic mean.
@@ -171,7 +171,7 @@ def binary_fbeta_score(  # pylint: disable=too-many-arguments
         target=target, preds=preds, pos_label=pos_label
     )
 
-    return _fbeta_reduce(
+    f_score = _fbeta_reduce(
         tp=tp,
         fp=fp,
         fn=fn,
@@ -180,23 +180,25 @@ def binary_fbeta_score(  # pylint: disable=too-many-arguments
         zero_division=zero_division,
     )
 
+    return cast(float, f_score)
+
 
 def multiclass_fbeta_score(  # pylint: disable=too-many-arguments
-    target: ArrayLike,
-    preds: ArrayLike,
+    target: npt.ArrayLike,
+    preds: npt.ArrayLike,
     beta: float,
     num_classes: int,
     top_k: Optional[int] = None,
     average: Literal["micro", "macro", "weighted", None] = None,
     zero_division: Literal["warn", 0, 1] = "warn",
-) -> Union[float, np.ndarray]:
+) -> Union[float, npt.NDArray[np.float_]]:
     """Compute the F-beta score for multiclass data.
 
     Parameters
     ----------
-    target : ArrayLike
+    target : npt.ArrayLike
         Ground truth (correct) target values.
-    preds : ArrayLike
+    preds : npt.ArrayLike
         Predictions as returned by a classifier.
     beta : float
         Weight of precision in harmonic mean.
@@ -264,22 +266,22 @@ def multiclass_fbeta_score(  # pylint: disable=too-many-arguments
 
 
 def multilabel_fbeta_score(  # pylint: disable=too-many-arguments
-    target: ArrayLike,
-    preds: ArrayLike,
+    target: npt.ArrayLike,
+    preds: npt.ArrayLike,
     beta: float,
     num_labels: int,
     threshold: float = 0.5,
     top_k: Optional[int] = None,
     average: Literal["micro", "macro", "weighted", None] = None,
     zero_division: Literal["warn", 0, 1] = "warn",
-):
+) -> Union[float, npt.NDArray[np.float_]]:
     """Compute the F-beta score for multilabel data.
 
     Parameters
     ----------
-    target : ArrayLike
+    target : npt.ArrayLike
         Ground truth (correct) target values.
-    preds : ArrayLike
+    preds : npt.ArrayLike
         Predictions as returned by a classifier.
     beta : float
         Weight of precision in harmonic mean.
@@ -350,25 +352,25 @@ def multilabel_fbeta_score(  # pylint: disable=too-many-arguments
 
 
 def fbeta_score(  # pylint: disable=too-many-arguments
-    target: ArrayLike,
-    preds: ArrayLike,
+    target: npt.ArrayLike,
+    preds: npt.ArrayLike,
     beta: float,
     task: Literal["binary", "multiclass", "multilabel"],
     pos_label: int = 1,
-    num_classes: int = None,
+    num_classes: Optional[int] = None,
     threshold: float = 0.5,
     top_k: Optional[int] = None,
-    num_labels: int = None,
+    num_labels: Optional[int] = None,
     average: Literal["micro", "macro", "weighted", None] = None,
     zero_division: Literal["warn", 0, 1] = "warn",
-) -> Union[float, np.ndarray]:
+) -> Union[float, npt.NDArray[np.float_]]:
     """Compute the F-beta score for binary, multiclass, or multilabel data.
 
     Parameters
     ----------
-    target : ArrayLike
+    target : npt.ArrayLike
         Ground truth (correct) target values.
-    preds : ArrayLike
+    preds : npt.ArrayLike
         Estimated targets as returned by a classifier.
     beta : float
         Weight of precision in harmonic mean.
@@ -441,7 +443,7 @@ def fbeta_score(  # pylint: disable=too-many-arguments
 
     """
     if task == "binary":
-        score = binary_fbeta_score(
+        return binary_fbeta_score(
             target,
             preds,
             beta,
@@ -449,24 +451,24 @@ def fbeta_score(  # pylint: disable=too-many-arguments
             threshold=threshold,
             zero_division=zero_division,
         )
-    elif task == "multiclass":
+    if task == "multiclass":
         assert (
             isinstance(num_classes, int) and num_classes > 0
         ), "Number of classes must be specified for multiclass classification."
-        score = multiclass_fbeta_score(
+        return multiclass_fbeta_score(
             target,
             preds,
             beta,
             num_classes,
             top_k=top_k,
-            average=average,  # type: ignore
+            average=average,
             zero_division=zero_division,
         )
-    elif task == "multilabel":
+    if task == "multilabel":
         assert (
             isinstance(num_labels, int) and num_labels > 0
         ), "Number of labels must be specified for multilabel classification."
-        score = multilabel_fbeta_score(
+        return multilabel_fbeta_score(
             target,
             preds,
             beta,
@@ -476,18 +478,16 @@ def fbeta_score(  # pylint: disable=too-many-arguments
             average=average,
             zero_division=zero_division,
         )
-    else:
-        raise ValueError(
-            f"Task {task} is not supported, expected one of 'binary', 'multiclass'"
-            " or 'multilabel'"
-        )
 
-    return score
+    raise ValueError(
+        f"Task {task} is not supported, expected one of 'binary', 'multiclass'"
+        " or 'multilabel'"
+    )
 
 
 def binary_f1_score(  # pylint: disable=too-many-arguments
-    target: ArrayLike,
-    preds: ArrayLike,
+    target: npt.ArrayLike,
+    preds: npt.ArrayLike,
     pos_label: int = 1,
     threshold: float = 0.5,
     zero_division: Literal["warn", 0, 1] = "warn",
@@ -534,20 +534,20 @@ def binary_f1_score(  # pylint: disable=too-many-arguments
 
 
 def multiclass_f1_score(  # pylint: disable=too-many-arguments
-    target: ArrayLike,
-    preds: ArrayLike,
+    target: npt.ArrayLike,
+    preds: npt.ArrayLike,
     num_classes: int,
     top_k: Optional[int] = None,
     average: Literal["micro", "macro", "weighted", None] = None,
     zero_division: Literal["warn", 0, 1] = "warn",
-) -> Union[float, np.ndarray]:
+) -> Union[float, npt.NDArray[np.float_]]:
     """Compute the F1 score for multiclass classification tasks.
 
     Parameters
     ----------
-    target : ArrayLike
+    target : npt.ArrayLike
         Ground truth (correct) target values.
-    preds : ArrayLike
+    preds : npt.ArrayLike
         Predictions as returned by a classifier.
     num_classes : int
         Number of classes in the dataset.
@@ -599,21 +599,21 @@ def multiclass_f1_score(  # pylint: disable=too-many-arguments
 
 
 def multilabel_f1_score(  # pylint: disable=too-many-arguments
-    target: ArrayLike,
-    preds: ArrayLike,
+    target: npt.ArrayLike,
+    preds: npt.ArrayLike,
     num_labels: int,
     threshold: float = 0.5,
     top_k: Optional[int] = None,
     average: Literal["micro", "macro", "weighted", None] = None,
     zero_division: Literal["warn", 0, 1] = "warn",
-):
+) -> Union[float, npt.NDArray[np.float_]]:
     """Compute the F1 score for multilabel classification tasks.
 
     Parameters
     ----------
-    target : ArrayLike
+    target : npt.ArrayLike
         Ground truth (correct) target values.
-    preds : ArrayLike
+    preds : npt.ArrayLike
         Predictions as returned by a classifier.
     num_labels : int
         Number of labels for the task.
@@ -666,24 +666,24 @@ def multilabel_f1_score(  # pylint: disable=too-many-arguments
 
 
 def f1_score(  # pylint: disable=too-many-arguments
-    target: ArrayLike,
-    preds: ArrayLike,
+    target: npt.ArrayLike,
+    preds: npt.ArrayLike,
     task: Literal["binary", "multiclass", "multilabel"],
     pos_label: int = 1,
-    num_classes: int = None,
+    num_classes: Optional[int] = None,
     threshold: float = 0.5,
     top_k: Optional[int] = None,
-    num_labels: int = None,
+    num_labels: Optional[int] = None,
     average: Literal["micro", "macro", "weighted", None] = None,
     zero_division: Literal["warn", 0, 1] = "warn",
-) -> Union[float, np.ndarray]:
+) -> Union[float, npt.NDArray[np.float_]]:
     """Compute the F1 score for multiclass data.
 
     Parameters
     ----------
-    target : ArrayLike
+    target : npt.ArrayLike
         Ground truth (correct) target values.
-    preds : ArrayLike
+    preds : npt.ArrayLike
         Estimated targets as returned by a classifier.
     task : Literal["binary", "multiclass", "multilabel"]
         Type of classification task.
