@@ -2,11 +2,12 @@
 
 import os
 import pickle
-from typing import Tuple, Union
+from typing import Optional, Tuple, Union
 
 import numpy as np
 import torch
 import torchxrayvision as xrv
+from datasets.arrow_dataset import Dataset
 from sklearn.decomposition import PCA, KernelPCA
 from sklearn.manifold import Isomap
 from sklearn.mixture import GaussianMixture
@@ -66,7 +67,7 @@ class Reductor:
                   If this behavior is not desired, use n_components directly.
     n_components: int
         The number of components to use for {"PCA", "SRP", "kPCA", "Isomap"}.
-        Must be defined for torch datasets.
+        Must be defined for huggingface datasets.
     gmm_n_clusters: int
         The number of clusters to use for "GMM".
     random_state: int
@@ -77,14 +78,13 @@ class Reductor:
     def __init__(
         self,
         dr_method: str,
-        model_path: str = None,
+        model_path: Optional[str] = None,
         var_ret: float = 0.8,
-        n_components: int = None,
-        n_features: int = None,
-        n_classes: int = None,
+        n_components: Optional[int] = None,
+        n_features: Optional[int] = None,
+        n_classes: Optional[int] = None,
         random_state: int = 42,
     ):
-
         self.dr_method = dr_method
         self.model_path = model_path
         self.var_ret = var_ret
@@ -218,7 +218,7 @@ class Reductor:
         pca.fit(X)
         return pca.n_components_
 
-    def fit(self, data: Union[np.ndarray, torch.utils.data.Dataset]):
+    def fit(self, data: Union[np.ndarray, Dataset]):
         """Fit the reductor to the data.
 
         For pre-trained or untrained models,
@@ -226,13 +226,12 @@ class Reductor:
 
         Parameters
         ----------
-        data: np.ndarray or torch.utils.data.Dataset
+        data: np.ndarray or huggingface Dataset
             Data to fit the reductor of shape (n_samples, n_features).
 
         """
-        # check if data is a numpy matrix or a torch dataset
+        # check if data is a numpy matrix or a huggingface dataset
         if isinstance(data, np.ndarray):
-
             if self.dr_method in ("PCA", "SRP", "kPCA", "Isomap", "GMM"):
                 if self.n_components is None:
                     self.n_components = self.get_dr_amount(data)
@@ -240,29 +239,30 @@ class Reductor:
                 self.model = self.model(n_components=self.n_components)
                 self.model.fit(data)
 
-        elif isinstance(data, torch.utils.data.Dataset):
+        elif isinstance(data, Dataset):
             pass
 
         else:
             raise ValueError(
-                "data must be a numpy matrix (n_samples, n_features) or a torch Dataset"
+                "data must be a numpy matrix (n_samples, n_features) \
+                     or a huggingface Dataset"
             )
 
     def transform(
         self,
-        data: Union[np.ndarray, torch.utils.data.Dataset],
+        data: Union[np.ndarray, Dataset],
         batch_size: int = 32,
-        num_workers: int = None,
+        num_workers: Optional[int] = None,
         progress: bool = True,
     ) -> Union[np.ndarray, Tuple[np.ndarray, np.ndarray]]:
         """Transform the data using the chosen dimensionality reduction method.
 
         Parameters
         ----------
-        data: np.ndarray (n_samples, n_features) or torch Dataset
+        data: np.ndarray (n_samples, n_features) or huggingface Dataset
             data to transform.
         batch_size: int
-            batch size for LSTM inference/pytorch dataloader. Default: 32
+            batch size for pytorch dataloader. Default: 32
         num_workers: int
             number of workers for pytorch dataloader. If None, uses max number of cpus.
 
@@ -282,7 +282,7 @@ class Reductor:
         if self.dr_method in ("PCA", "SRP", "kPCA", "Isomap"):
             if isinstance(data, np.ndarray):
                 X_transformed = self.model.transform(data)
-            elif isinstance(data, torch.utils.data.Dataset):
+            elif isinstance(data, Dataset):
                 dataloader = DataLoader(
                     data, batch_size=batch_size, num_workers=num_workers
                 )
@@ -293,8 +293,10 @@ class Reductor:
         elif self.dr_method == "NoRed":
             if isinstance(data, np.ndarray):
                 X_transformed = data
-            elif isinstance(data, torch.utils.data.Dataset):
-                raise NotImplementedError("NoRed not implemented for torch datasets")
+            elif isinstance(data, Dataset):
+                raise NotImplementedError(
+                    "NoRed not implemented for huggingface datasets"
+                )
         elif "BBSDs" in self.dr_method:
             if "txrv_CNN" in self.dr_method:
                 dataloader = DataLoader(
@@ -513,20 +515,16 @@ class Reductor:
 
         """
         all_preds = []
-        all_labels = []
         model = model.to(self.device).eval()
         for batch in tqdm(dataloader) if progress else dataloader:
-            imgs = batch["img"]
-            labels = batch["lab"]
+            imgs = batch["features"]
             imgs = imgs.to(self.device)
             with torch.no_grad():
                 preds = model(imgs)
             preds = preds.cpu().numpy()
             all_preds.append(preds)
-            all_labels.append(labels)
         X_transformed = np.concatenate(all_preds)
-        labels = np.concatenate(all_labels)
-        return X_transformed, labels
+        return X_transformed, None
 
     def xrv_ae_inference(
         self, model: nn.Module, dataloader: DataLoader, progress=True
@@ -547,17 +545,13 @@ class Reductor:
 
         """
         all_preds = []
-        all_labels = []
         model = model.to(self.device).eval()
         for batch in tqdm(dataloader) if progress else dataloader:
-            imgs = batch["img"]
-            labels = batch["lab"]
+            imgs = batch["features"]
             imgs = imgs.to(self.device)
             with torch.no_grad():
                 preds = model.encode(imgs).mean(dim=(2, 3))
             preds = preds.cpu().numpy()
             all_preds.append(preds)
-            all_labels.append(labels)
         X_transformed = np.concatenate(all_preds)
-        labels = np.concatenate(all_labels)
-        return X_transformed, labels
+        return X_transformed, None
