@@ -2,7 +2,7 @@
 
 import logging
 from dataclasses import asdict, dataclass, field
-from typing import Callable, Dict, Literal, Optional, Union
+from typing import Any, Callable, Dict, Literal, Optional, Union
 
 import dask.dataframe as dd
 import pandas as pd
@@ -48,8 +48,8 @@ class QueryInterface:
     query: TableTypes
     join: Optional[qo.JoinArgs] = None
     ops: Optional[qo.Sequential] = None
-    _data: Optional[Union[pd.DataFrame, dd.DataFrame]] = None
-    _run_args: Dict = field(default_factory=dict)
+    _data: Optional[Union[pd.DataFrame, dd.core.DataFrame]] = None
+    _run_args: Dict[str, Any] = field(default_factory=dict)
 
     def __post_init__(self) -> None:
         """Post init method to chain operations with original query."""
@@ -59,7 +59,7 @@ class QueryInterface:
             self.query = self.ops(self.query)
 
     @property
-    def data(self) -> Optional[Union[pd.DataFrame, dd.DataFrame]]:
+    def data(self) -> Optional[Union[pd.DataFrame, dd.core.DataFrame]]:
         """Get data."""
         return self._data
 
@@ -69,7 +69,7 @@ class QueryInterface:
         backend: Literal["pandas", "dask"] = "pandas",
         index_col: Optional[str] = None,
         n_partitions: Optional[int] = None,
-    ) -> Union[pd.DataFrame, dd.DataFrame]:
+    ) -> Union[pd.DataFrame, dd.core.DataFrame]:
         """Run the query, and fetch data.
 
         Parameters
@@ -181,11 +181,11 @@ class QueryInterfaceProcessed:
 
     database: Database
     _query: TableTypes
-    process_fn: Callable
+    process_fn: Callable[..., Any]
     join: Optional[qo.JoinArgs] = None
     ops: Optional[qo.Sequential] = None
-    _data: Optional[Union[pd.DataFrame, dd.DataFrame, None]] = None
-    _run_args: Dict = field(default_factory=dict)
+    _data: Optional[Union[pd.DataFrame, dd.core.DataFrame, None]] = None
+    _run_args: Dict[str, Any] = field(default_factory=dict)
 
     def __post_init__(self) -> None:
         """Post init method to chain operations with original query."""
@@ -200,7 +200,7 @@ class QueryInterfaceProcessed:
         backend: Literal["pandas", "dask"] = "pandas",
         index_col: Optional[str] = None,
         n_partitions: Optional[int] = None,
-    ) -> Union[pd.DataFrame, dd.DataFrame]:
+    ) -> Union[pd.DataFrame, dd.core.DataFrame]:
         """Run the query, and fetch data.
 
         Parameters
@@ -241,7 +241,7 @@ class QueryInterfaceProcessed:
         return self._data
 
     @property
-    def data(self) -> Optional[Union[pd.DataFrame, dd.DataFrame]]:
+    def data(self) -> Optional[Union[pd.DataFrame, dd.core.DataFrame]]:
         """Get data."""
         return self._data
 
