@@ -6,7 +6,7 @@
 import logging
 from dataclasses import dataclass
 from functools import wraps
-from typing import Any, Callable, List, Optional, Union
+from typing import Any, Callable, Dict, List, Optional, Union
 
 import sqlalchemy
 from sqlalchemy import cast, func, select
@@ -744,7 +744,11 @@ def process_column(col: Column, **kwargs: bool) -> Column:
 
 
 def equals(
-    col: Column, value: Any, lower: bool = True, trim: bool = True, **kwargs: bool
+    col: Column,
+    value: Any,
+    lower: bool = True,
+    trim: bool = True,
+    **kwargs: Dict[str, bool],
 ) -> BinaryExpression:
     """Condition that a column has some value.
 
@@ -777,6 +781,96 @@ def equals(
     )
 
 
+def greater_than(
+    col: Column,
+    value: Any,
+    lower: bool = True,
+    trim: bool = True,
+    equal: bool = False,
+    **kwargs: Dict[str, bool],
+) -> BinaryExpression:
+    """Condition that a column is greater than some value.
+
+    Assumes that if searching for a string, both the value and column values
+    should be converted to lowercase and trimmed of leading/trailing whitespace.
+
+    Parameters
+    ----------
+    col : sqlalchemy.sql.schema.Column
+        The column to condition.
+    val : Any
+        The value to match in the column.
+    lower : bool, default=True
+        Whether to convert the value and column to lowercase.
+        This is only relevant when the column/value are strings.
+    trim : bool, default=True
+        Whether to trim (strip) whitespace on the value and column.
+        This is only relevant when the column/value are strings.
+    equal: bool, default=False
+        Whether to also include equal to the value.
+    **kwargs : dict, optional
+        Remaining preprocessing keyword arguments.
+
+    Returns
+    -------
+    sqlalchemy.sql.elements.BinaryExpression
+        An expression representing where the condition was satisfied.
+
+    """
+    if equal:
+        return process_column(col, lower=lower, trim=trim, **kwargs) >= process_elem(
+            value, lower=lower, trim=trim, **kwargs
+        )
+    return process_column(col, lower=lower, trim=trim, **kwargs) > process_elem(
+        value, lower=lower, trim=trim, **kwargs
+    )
+
+
+def less_than(
+    col: Column,
+    value: Any,
+    lower: bool = True,
+    trim: bool = True,
+    equal: bool = False,
+    **kwargs: Dict[str, bool],
+) -> BinaryExpression:
+    """Condition that a column is less than some value.
+
+    Assumes that if searching for a string, both the value and column values
+    should be converted to lowercase and trimmed of leading/trailing whitespace.
+
+    Parameters
+    ----------
+    col : sqlalchemy.sql.schema.Column
+        The column to condition.
+    val : Any
+        The value to match in the column.
+    lower : bool, default=True
+        Whether to convert the value and column to lowercase.
+        This is only relevant when the column/value are strings.
+    trim : bool, default=True
+        Whether to trim (strip) whitespace on the value and column.
+        This is only relevant when the column/value are strings.
+    equal: bool, default=False
+        Whether to also include equal to the value.
+    **kwargs : dict, optional
+        Remaining preprocessing keyword arguments.
+
+    Returns
+    -------
+    sqlalchemy.sql.elements.BinaryExpression
+        An expression representing where the condition was satisfied.
+
+    """
+    if equal:
+        return process_column(col, lower=lower, trim=trim, **kwargs) <= process_elem(
+            value, lower=lower, trim=trim, **kwargs
+        )
+    return process_column(col, lower=lower, trim=trim, **kwargs) < process_elem(
+        value, lower=lower, trim=trim, **kwargs
+    )
+
+
 def not_equals(
     col: Column, value: Any, lower: bool = True, trim: bool = True, **kwargs: bool
 ) -> BinaryExpression:
@@ -844,7 +938,7 @@ def has_string_format(
 
 
 def has_substring(
-    col: Column, substring: Any, lower: bool = True, **kwargs: bool
+    col: Column, substring: Any, lower: bool = True, **kwargs: Dict[str, bool]
 ) -> BinaryExpression:
     """Condition that a column has some substring.
 
@@ -873,7 +967,11 @@ def has_substring(
 
 
 def starts_with(
-    col: Column, value: Any, lower: bool = True, trim: bool = True, **kwargs: bool
+    col: Column,
+    value: Any,
+    lower: bool = True,
+    trim: bool = True,
+    **kwargs: Dict[str, bool],
 ) -> BinaryExpression:
     """Condition that a column starts with some value/string.
 
@@ -906,7 +1004,11 @@ def starts_with(
 
 
 def ends_with(
-    col: Column, value: Any, lower: bool = True, trim: bool = True, **kwargs: bool
+    col: Column,
+    value: Any,
+    lower: bool = True,
+    trim: bool = True,
+    **kwargs: Dict[str, bool],
 ) -> BinaryExpression:
     """Condition that a column ends with some value/string.
 
@@ -939,7 +1041,11 @@ def ends_with(
 
 
 def in_(
-    col: Column, lst: List[Any], lower: bool = True, trim: bool = True, **kwargs: bool
+    col: Column,
+    lst: List[Any],
+    lower: bool = True,
+    trim: bool = True,
+    **kwargs: Dict[str, bool],
 ) -> BinaryExpression:
     """Condition that a column value is in a list of values.
 
